@@ -9,7 +9,6 @@
 #include "oxygendecoration.h"
 
 #include "config-oxygen.h"
-#include "config/oxygenconfigwidget.h"
 #include "oxygensettingsprovider.h"
 #include "oxygenshadowcache.h"
 
@@ -29,15 +28,10 @@
 #include <QTimer>
 
 #if OXYGEN_HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <private/qtx11extras_p.h>
 #endif
-#endif
 
-K_PLUGIN_FACTORY_WITH_JSON(OxygenDecoFactory, "oxygen.json", registerPlugin<Oxygen::Decoration>(); registerPlugin<Oxygen::Button>();
-                           registerPlugin<Oxygen::ConfigWidget>();)
+K_PLUGIN_FACTORY_WITH_JSON(OxygenDecoFactory, "oxygen.json", registerPlugin<Oxygen::Decoration>(); registerPlugin<Oxygen::Button>();)
 
 namespace Oxygen
 {
@@ -46,8 +40,7 @@ using KDecoration2::ColorGroup;
 using KDecoration2::ColorRole;
 
 //________________________________________________________________
-using DecorationShadowPointer = QSharedPointer<KDecoration2::DecorationShadow>;
-using ShadowMap = QHash<int, DecorationShadowPointer>;
+using ShadowMap = QHash<int, std::shared_ptr<KDecoration2::DecorationShadow>>;
 
 static int g_sDecoCount = 0;
 static ShadowMap g_sShadows;
@@ -89,7 +82,7 @@ QColor Decoration::titleBarColor(const QPalette &palette) const
         return KColorUtils::mix(titleBarColor(palette, false), titleBarColor(palette, true), m_opacity);
 
     } else {
-        return titleBarColor(palette, client().toStrongRef()->isActive());
+        return titleBarColor(palette, client()->isActive());
     }
 }
 
@@ -100,7 +93,7 @@ QColor Decoration::titleBarColor(const QPalette &palette, bool active) const
         return palette.color(active ? QPalette::Active : QPalette::Inactive, QPalette::Window);
 
     } else {
-        return client().toStrongRef()->color(active ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::TitleBar);
+        return client()->color(active ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::TitleBar);
     }
 }
 
@@ -113,7 +106,7 @@ QColor Decoration::fontColor(const QPalette &palette) const
         return KColorUtils::mix(fontColor(palette, false), fontColor(palette, true), m_opacity);
 
     } else {
-        return fontColor(palette, client().toStrongRef()->isActive());
+        return fontColor(palette, client()->isActive());
     }
 }
 
@@ -124,7 +117,7 @@ QColor Decoration::fontColor(const QPalette &palette, bool active) const
         return palette.color(active ? QPalette::Active : QPalette::Disabled, QPalette::WindowText);
 
     } else {
-        return client().toStrongRef()->color(active ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::Foreground);
+        return client()->color(active ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::Foreground);
     }
 }
 
@@ -134,7 +127,7 @@ QColor Decoration::contrastColor(const QPalette &palette) const
     if (m_internalSettings->useWindowColors())
         return contrastColor(palette.color(QPalette::Window));
     else {
-        const auto cl = client().toStrongRef();
+        const auto cl = client();
         return contrastColor(cl->color(cl->isActive() ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::TitleBar));
     }
 }
@@ -146,7 +139,7 @@ QColor Decoration::contrastColor(const QColor &color) const
 }
 
 //________________________________________________________________
-void Decoration::init()
+bool Decoration::init()
 {
     // active state change animation
     m_animation->setStartValue(0);
@@ -158,22 +151,22 @@ void Decoration::init()
     reconfigure();
     updateTitleBar();
     auto s = settings();
-    connect(s.data(), &KDecoration2::DecorationSettings::borderSizeChanged, this, &Decoration::recalculateBorders);
+    connect(s.get(), &KDecoration2::DecorationSettings::borderSizeChanged, this, &Decoration::recalculateBorders);
 
     // a change in font might cause the borders to change
-    connect(s.data(), &KDecoration2::DecorationSettings::fontChanged, this, &Decoration::recalculateBorders);
-    connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::recalculateBorders);
+    connect(s.get(), &KDecoration2::DecorationSettings::fontChanged, this, &Decoration::recalculateBorders);
+    connect(s.get(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::recalculateBorders);
 
     // buttons
-    connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::updateButtonsGeometryDelayed);
-    connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsLeftChanged, this, &Decoration::updateButtonsGeometryDelayed);
-    connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsRightChanged, this, &Decoration::updateButtonsGeometryDelayed);
+    connect(s.get(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::updateButtonsGeometryDelayed);
+    connect(s.get(), &KDecoration2::DecorationSettings::decorationButtonsLeftChanged, this, &Decoration::updateButtonsGeometryDelayed);
+    connect(s.get(), &KDecoration2::DecorationSettings::decorationButtonsRightChanged, this, &Decoration::updateButtonsGeometryDelayed);
 
     // full reconfiguration
-    connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, this, &Decoration::reconfigure);
-    connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, SettingsProvider::self(), &SettingsProvider::reconfigure, Qt::UniqueConnection);
+    connect(s.get(), &KDecoration2::DecorationSettings::reconfigured, this, &Decoration::reconfigure);
+    connect(s.get(), &KDecoration2::DecorationSettings::reconfigured, SettingsProvider::self(), &SettingsProvider::reconfigure, Qt::UniqueConnection);
 
-    const auto *cl = client().toStrongRef().data();
+    const auto *cl = client();
     connect(cl, &KDecoration2::DecoratedClient::adjacentScreenEdgesChanged, this, &Decoration::recalculateBorders);
     connect(cl, &KDecoration2::DecoratedClient::maximizedHorizontallyChanged, this, &Decoration::recalculateBorders);
     connect(cl, &KDecoration2::DecoratedClient::maximizedVerticallyChanged, this, &Decoration::recalculateBorders);
@@ -198,6 +191,7 @@ void Decoration::init()
 
     createButtons();
     updateShadow();
+    return true;
 }
 
 //________________________________________________________________
@@ -205,7 +199,7 @@ void Decoration::updateTitleBar()
 {
     auto s = settings();
     const bool maximized = isMaximized();
-    const auto clientPtr = client().toStrongRef();
+    const auto clientPtr = client();
     const int width = maximized ? clientPtr->width() : clientPtr->width() - 2 * s->largeSpacing() * Metrics::TitleBar_SideMargin;
     const int height = maximized ? borderTop() : borderTop() - s->smallSpacing() * Metrics::TitleBar_TopMargin;
     const int x = maximized ? 0 : s->largeSpacing() * Metrics::TitleBar_SideMargin;
@@ -217,7 +211,7 @@ void Decoration::updateTitleBar()
 void Decoration::updateAnimationState()
 {
     if (m_internalSettings->animationsEnabled()) {
-        m_animation->setDirection(client().toStrongRef()->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward);
+        m_animation->setDirection(client()->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward);
         if (m_animation->state() != QPropertyAnimation::Running)
             m_animation->start();
 
@@ -229,7 +223,7 @@ void Decoration::updateAnimationState()
 //________________________________________________________________
 void Decoration::updateSizeGripVisibility()
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     if (m_sizeGrip) {
         m_sizeGrip->setVisible(c->isResizeable() && !isMaximized() && !c->isShaded());
     }
@@ -312,7 +306,7 @@ void Decoration::reconfigure()
 void Decoration::recalculateBorders()
 {
     auto s = settings();
-    const auto c = client().toStrongRef();
+    const auto c = client();
     const auto edges = c->adjacentScreenEdges();
 
     // left, right and bottom borders
@@ -381,14 +375,14 @@ void Decoration::updateButtonsGeometry()
     const int bWidth = buttonHeight();
     const int verticalOffset = (isMaximized() ? s->smallSpacing() * Metrics::TitleBar_TopMargin : 0) + (captionHeight() - buttonHeight()) / 2;
 
-    const QVector<QPointer<KDecoration2::DecorationButton>> leftButtons = m_leftButtons->buttons();
-    const QVector<QPointer<KDecoration2::DecorationButton>> rightButtons = m_rightButtons->buttons();
+    const QVector<KDecoration2::DecorationButton *> leftButtons = m_leftButtons->buttons();
+    const QVector<KDecoration2::DecorationButton *> rightButtons = m_rightButtons->buttons();
 
     const auto allButtons = leftButtons + rightButtons;
     for (const auto &button : allButtons) {
-        button.data()->setGeometry(QRectF(QPoint(0, 0), QSizeF(bWidth, bHeight)));
-        static_cast<Button *>(button.data())->setOffset(QPointF(0, verticalOffset));
-        static_cast<Button *>(button.data())->setIconSize(QSize(bWidth, bWidth));
+        button->setGeometry(QRectF(QPoint(0, 0), QSizeF(bWidth, bHeight)));
+        static_cast<Button *>(button)->setOffset(QPointF(0, verticalOffset));
+        static_cast<Button *>(button)->setIconSize(QSize(bWidth, bWidth));
     }
 
     // left buttons
@@ -401,7 +395,7 @@ void Decoration::updateButtonsGeometry()
         const int hPadding = s->smallSpacing() * Metrics::TitleBar_SideMargin;
         if (isMaximizedHorizontally()) {
             // add offsets on the side buttons, to preserve padding, but satisfy Fitts law
-            auto button = static_cast<Button *>(leftButtons.front().data());
+            auto button = static_cast<Button *>(leftButtons.front());
             button->setGeometry(QRectF(QPoint(0, 0), QSizeF(bWidth + hPadding, bHeight)));
             button->setFlag(Button::FlagFirstInList);
             button->setHorizontalOffset(hPadding);
@@ -421,7 +415,7 @@ void Decoration::updateButtonsGeometry()
         const int vPadding = isMaximized() ? 0 : s->smallSpacing() * Metrics::TitleBar_TopMargin;
         const int hPadding = s->smallSpacing() * Metrics::TitleBar_SideMargin;
         if (isMaximizedHorizontally()) {
-            auto button = static_cast<Button *>(rightButtons.back().data());
+            auto button = static_cast<Button *>(rightButtons.back());
             button->setGeometry(QRectF(QPoint(0, 0), QSizeF(bWidth + hPadding, bHeight)));
             button->setFlag(Button::FlagLastInList);
 
@@ -437,7 +431,7 @@ void Decoration::updateButtonsGeometry()
 //________________________________________________________________
 void Decoration::paint(QPainter *painter, const QRect &repaintRegion)
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     const auto palette = c->palette();
 
     const auto rect = c->isShaded() ? QRect(QPoint(0, 0), QSize(size().width(), borderTop())) : this->rect();
@@ -507,7 +501,7 @@ QPair<QRect, Qt::Alignment> Decoration::captionRect() const
         case InternalSettings::AlignCenterFullWidth: {
             // full caption rect
             const QRect fullRect = QRect(0, yOffset, size().width(), captionHeight());
-            QRect boundingRect(settings()->fontMetrics().boundingRect(client().toStrongRef()->caption()).toRect());
+            QRect boundingRect(settings()->fontMetrics().boundingRect(client()->caption()).toRect());
 
             // text bounding rect
             boundingRect.setTop(yOffset);
@@ -539,7 +533,7 @@ void Decoration::updateShadow()
 
     // generate key
     ShadowCache::Key key;
-    const auto clientPtr = client().toStrongRef();
+    const auto clientPtr = client();
     key.active = SettingsProvider::self()->shadowCache()->isEnabled(QPalette::Active) && clientPtr->isActive();
     key.isShade = clientPtr->isShaded();
     key.hasBorder = !hasNoBorders();
@@ -554,7 +548,7 @@ void Decoration::updateShadow()
     // find key in map
     auto iter = g_sShadows.find(hash);
     if (iter == g_sShadows.end()) {
-        auto decorationShadow = DecorationShadowPointer::create();
+        auto decorationShadow = std::make_shared<KDecoration2::DecorationShadow>();
         QPixmap shadowPixmap =
             animated ? SettingsProvider::self()->shadowCache()->animatedPixmap(key, m_opacity) : SettingsProvider::self()->shadowCache()->pixmap(key);
 
@@ -588,7 +582,7 @@ void Decoration::renderCorners(QPainter *painter, const QRect &frame, const QPal
 //_________________________________________________________
 void Decoration::renderWindowBackground(QPainter *painter, const QRect &clipRect, const QPalette &palette) const
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     auto innerClientRect = c->isShaded() ? QRect(QPoint(0, 0), QSize(size().width(), borderTop())) : rect();
 
     // size of window minus the outlines for the rounded corners
@@ -632,7 +626,7 @@ void Decoration::renderTitleText(QPainter *painter, const QPalette &palette) con
     const auto cR = captionRect();
 
     // copy caption
-    const QString caption = painter->fontMetrics().elidedText(client().toStrongRef()->caption(), Qt::ElideMiddle, cR.first.width());
+    const QString caption = painter->fontMetrics().elidedText(client()->caption(), Qt::ElideMiddle, cR.first.width());
 
     const auto contrast(contrastColor(palette));
     if (contrast.isValid()) {
@@ -658,17 +652,11 @@ void Decoration::createSizeGrip(void)
     if (!QX11Info::isPlatformX11())
         return;
 
-    // access client
-    const auto clientPtr = client().toStrongRef();
-    if (!clientPtr)
-        return;
-
-    if (clientPtr->windowId() != 0) {
+    if (client()->windowId() != 0) {
         m_sizeGrip = new SizeGrip(this);
-        const auto *clientP = clientPtr.data();
-        connect(clientP, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateSizeGripVisibility);
-        connect(clientP, &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateSizeGripVisibility);
-        connect(clientP, &KDecoration2::DecoratedClient::resizeableChanged, this, &Decoration::updateSizeGripVisibility);
+        connect(client(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateSizeGripVisibility);
+        connect(client(), &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateSizeGripVisibility);
+        connect(client(), &KDecoration2::DecoratedClient::resizeableChanged, this, &Decoration::updateSizeGripVisibility);
     }
 #endif
 }
