@@ -7,13 +7,22 @@
 
 #include <KPluginFactory>
 
-K_PLUGIN_FACTORY(OxygenStyleConfigFactory, registerPlugin<Oxygen::ConfigurationModule>();)
+K_PLUGIN_FACTORY_WITH_JSON(OxygenStyleConfigFactory, "oxygenstyleconfig.json", registerPlugin<Oxygen::ConfigurationModule>();)
 
 #include "oxygenstyleconfigmodule.moc"
 
 namespace Oxygen
 {
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+ConfigurationModule::ConfigurationModule(QObject *parent, const KPluginMetaData &metaData)
+    : KCModule(parent, metaData)
+{
+    widget()->setLayout(new QVBoxLayout(widget()));
+    widget()->layout()->addWidget(m_config = new StyleConfig(widget()));
+    connect(m_config, &StyleConfig::changed, this, &KCModule::setNeedsSave);
+}
+#else
 //_______________________________________________________________________
 ConfigurationModule::ConfigurationModule(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
@@ -22,6 +31,7 @@ ConfigurationModule::ConfigurationModule(QWidget *parent, const QVariantList &ar
     layout()->addWidget(m_config = new StyleConfig(this));
     connect(m_config, static_cast<void (StyleConfig::*)(bool)>(&StyleConfig::changed), this, static_cast<void (KCModule::*)(bool)>(&KCModule::changed));
 }
+#endif
 
 //_______________________________________________________________________
 void ConfigurationModule::defaults()
